@@ -23,9 +23,8 @@ def send_log_email():
     sender_email_configuration = SenderEmailConfiguration.objects.first()
     sender = sender_email_configuration.sender_email_address
 
-    email_configuration = EmailConfiguration.objects.values(
-        'Subject', 'Logo', 'Banner', 'Email_Content', 'Signature', 'Email_Us',
-        'FAQ_URL', 'Unsubscribe_Email_ID', 'Log_path', 'HTML_File').first()
+    email_configuration = EmailConfiguration.objects.filter(
+        Logs_Type='Attachment').all()
 
     send_notifications(email, sender, email_configuration)
 
@@ -33,8 +32,11 @@ def send_log_email():
 def send_log_email_with_msg(email, sender, msg):
     """ function to send emails of log file to personas"""
 
+    email_configuration = EmailConfiguration.objects.filter(
+        Logs_Type='Message').all()
+
     # Getting sender email id
-    send_notifications_with_msg(email, sender, msg)
+    send_notifications_with_msg(email, sender, msg, email_configuration)
 
 
 class Command(BaseCommand):
