@@ -57,9 +57,9 @@ def send_notifications(email, sender, email_configuration):
     RECIPIENT = email
 
     # Getting path of email cover picture and logo picture
-    cover = '/' + email_configuration.get('Banner')
+    cover = settings.MEDIA_ROOT + '/' + email_configuration.get('Banner')
     logger.info(cover)
-    logo = '/' + email_configuration.get('Logo')
+    logo = settings.MEDIA_ROOT + '/' + email_configuration.get('Logo')
     logger.info(logo)
     # The subject line for the email.
     SUBJECT = email_configuration.get('Subject')
@@ -103,7 +103,7 @@ def send_notifications(email, sender, email_configuration):
             continue
 
 
-def send_notifications_with_msg(email, sender, msg):
+def send_notifications_with_msg(email, sender, msg, email_configuration):
     """This function sends email of a log file """
 
     logger.info('Sending email to recipients')
@@ -114,17 +114,20 @@ def send_notifications_with_msg(email, sender, msg):
     # is still in the sandbox, this address must be verified.
     RECIPIENT = email
     # The subject line for the email.
-    SUBJECT = "New Message From OpenLXP Portal"
+    SUBJECT = email_configuration.get('Subject')
 
+    # Getting path of email cover picture and logo picture
+    cover = settings.MEDIA_ROOT + '/' + email_configuration.get('Banner')
+    logo = settings.MEDIA_ROOT + '/' + email_configuration.get('Logo')
     # # The HTML body of the email.
-    BODY_HTML = """\
-       <html>
-       <head></head>
-       <body>
-       <p>""" + msg + """</p>
-       </body>
-       </html>
-       """
+    file_name = email_configuration.get('HTML_File')
+    BODY_HTML = open('media/' + file_name).read().format(
+        cover=cover, logo=logo,
+        paragraph=msg,
+        signature=email_configuration.get('Signature'),
+        email_us=email_configuration.get('Email_Us'),
+        faq_url=email_configuration.get('FAQ_URL'),
+        unsubscribe=email_configuration.get('Unsubscribe_Email_ID'))
 
     for each_recipient in RECIPIENT:
         try:
